# hdpl-conventions/ṕroof-of-concept/python/README.md

> Note: as 2021-04-12, the HDPLisp does not have even early work ported to
  Python language **but HDP Declarative Programming do have**. See also
  [hdp-conventions/README.md](hdp-conventions/README.md)